# mastodon

![Version: 4.1.0](https://img.shields.io/badge/Version-4.1.0-informational?style=flat-square) ![Type: application](https://img.shields.io/badge/Type-application-informational?style=flat-square) ![AppVersion: v4.1.4](https://img.shields.io/badge/AppVersion-v4.1.4-informational?style=flat-square)

Mastodon is a free, open-source social network server based on ActivityPub.

## Requirements

| Repository | Name | Version |
|------------|------|---------|
| oci://registry-1.docker.io/bitnamicharts | elasticsearch | 19.10.1 |
| oci://registry-1.docker.io/bitnamicharts | postgresql | 12.6.0 |
| oci://registry-1.docker.io/bitnamicharts | redis | 17.11.6 |

## Values

| Key | Type | Default | Description |
|-----|------|---------|-------------|
| affinity | object | `{}` | Affinity for all pods unless overwritten |
| deploymentAnnotations | object | `{}` |  |
| elasticsearch | object | `{}` | https://github.com/bitnami/charts/tree/master/bitnami/elasticsearch#parameters |
| externalAuth.cas.enabled | bool | `false` |  |
| externalAuth.ldap.enabled | bool | `false` |  |
| externalAuth.oauth_global.omniauth_only | bool | `false` | Automatically redirect to OIDC, CAS or SAML, and don't use local account authentication when clicking on Sign-In |
| externalAuth.oidc.enabled | bool | `false` | OpenID Connect support is proposed in PR #16221 and awaiting merge. |
| externalAuth.pam.enabled | bool | `false` |  |
| externalAuth.saml.enabled | bool | `false` |  |
| fullnameOverride | string | `""` |  |
| image.pullPolicy | string | `"IfNotPresent"` | image pullPolicy - use `Always` when using `latest` tag |
| image.repository | string | `"ghcr.io/mastodon/mastodon"` | image repository to use |
| image.tag | string | `""` | docker tag. use `latest` for the latest release or `edge` for the image built from the most recent commit |
| ingress.annotations | string | `nil` |  |
| ingress.enabled | bool | `true` |  |
| ingress.hosts[0].host | string | `"mastodon.local"` |  |
| ingress.hosts[0].paths[0].path | string | `"/"` |  |
| ingress.ingressClassName | string | `nil` | you can specify the ingressClassName if it differs from the default |
| ingress.tls[0].hosts[0] | string | `"mastodon.local"` |  |
| ingress.tls[0].secretName | string | `"mastodon-tls"` |  |
| jobAnnotations | object | `{}` |  |
| mastodon.authorizedFetch | bool | `false` | Enables "Secure Mode" for more details see: https://docs.joinmastodon.org/admin/config/#authorized_fetch |
| mastodon.createAdmin | object | `{"existingSecret":"","secretKeys":{"emailKey":"email","passwordKey":"password","usernameKey":"username"}}` | create an initial administrator user; the password is autogenerated and will have to be reset |
| mastodon.cron.removeMedia | object | `{}` | run `tootctl media remove` every week |
| mastodon.limitedFederationMode | bool | `false` | Enables "Limited Federation Mode" for more detauls see: https://docs.joinmastodon.org/admin/config/#limited_federation_mode |
| mastodon.local_domain | string | `"mastodon.local"` |  |
| mastodon.locale | string | `"en"` | available locales: https://github.com/mastodon/mastodon/blob/main/config/application.rb#L71 |
| mastodon.metrics.statsd.address | string | `""` | Enable statsd publishing via STATSD_ADDR environment variable |
| mastodon.persistence.assets.accessMode | string | `"ReadWriteOnce"` | ReadWriteOnce is more widely supported than ReadWriteMany, but limits scalability, since it requires the Rails and Sidekiq pods to run on the same node. |
| mastodon.persistence.assets.existingClaim | string | `nil` | name of existing persistent volume claim to use for assets |
| mastodon.persistence.assets.resources.requests.storage | string | `"10Gi"` |  |
| mastodon.persistence.system.accessMode | string | `"ReadWriteOnce"` |  |
| mastodon.persistence.system.existingClaim | string | `nil` | name of existing persistent volume claim to use for system |
| mastodon.persistence.system.resources.requests.storage | string | `"100Gi"` |  |
| mastodon.preparedStatements | bool | `true` |  |
| mastodon.s3.access_key | string | `""` |  |
| mastodon.s3.access_secret | string | `""` |  |
| mastodon.s3.alias_host | string | `""` | If you have a caching proxy, enter its base URL here. |
| mastodon.s3.bucket | string | `""` |  |
| mastodon.s3.enabled | bool | `false` |  |
| mastodon.s3.endpoint | string | `""` |  |
| mastodon.s3.existingSecret | string | `""` | you can also specify the name of an existing Secret with keys AWS_ACCESS_KEY_ID and AWS_SECRET_ACCESS_KEY |
| mastodon.s3.hostname | string | `""` |  |
| mastodon.s3.permission | string | `""` |  |
| mastodon.s3.region | string | `""` |  |
| mastodon.s3.secretKeys.s3AccessKey | string | `"AWS_SECRET_ACCESS_KEY"` |  |
| mastodon.s3.secretKeys.s3AccessKeyID | string | `"AWS_ACCESS_KEY_ID"` |  |
| mastodon.s3.secretKeys.s3Bucket | string | `""` |  |
| mastodon.s3.secretKeys.s3Endpoint | string | `""` |  |
| mastodon.s3.secretKeys.s3Hostname | string | `""` |  |
| mastodon.s3.secretKeys.s3Region | string | `""` |  |
| mastodon.secrets.existingSecret | string | `""` | the name of an existing Secret to use. keys must be: VAPID_PRIVATE_KEY, VAPID_PUBLIC_KEY, SECRET_KEY_BASE, OTP_SECRET |
| mastodon.secrets.otp_secret | string | `""` |  |
| mastodon.secrets.secret_key_base | string | `""` | must be set manually; autogenerated keys are rotated on each upgrade |
| mastodon.secrets.vapid.private_key | string | `""` |  |
| mastodon.secrets.vapid.public_key | string | `""` |  |
| mastodon.sidekiq.affinity | object | `{}` | Affinity for all Sidekiq Deployments unless overwritten, overwrites .Values.affinity |
| mastodon.sidekiq.podSecurityContext | object | `{}` | Pod security context for all Sidekiq Pods, overwrites .Values.podSecurityContext |
| mastodon.sidekiq.resources | object | `{}` | Resources for all Sidekiq Deployments unless overwritten |
| mastodon.sidekiq.securityContext | Sidekiq Container | `{}` | Security Context for all Pods, overwrites .Values.securityContext |
| mastodon.sidekiq.workers[0].affinity | object | `{}` | Affinity for this specific deployment, overwrites .Values.affinity and .Values.mastodon.sidekiq.affinity |
| mastodon.sidekiq.workers[0].concurrency | int | `25` | Number of threads / parallel sidekiq jobs that are executed per Pod |
| mastodon.sidekiq.workers[0].name | string | `"all-queues"` |  |
| mastodon.sidekiq.workers[0].queues | list | `["default,8","push,6","ingress,4","mailers,2","pull","scheduler"]` | Sidekiq queues for Mastodon that are handled by this worker. See https://docs.joinmastodon.org/admin/scaling/#concurrency See https://github.com/mperham/sidekiq/wiki/Advanced-Options#queues for how to weight queues as argument |
| mastodon.sidekiq.workers[0].replicas | int | `1` | Number of Pod replicas deployed by the Deployment |
| mastodon.sidekiq.workers[0].resources | object | `{}` | Resources for this specific deployment to allow optimised scaling, overwrites .Values.mastodon.sidekiq.resources |
| mastodon.singleUserMode | bool | `false` | If set to true, the frontpage of your Mastodon server will always redirect to the first profile in the database and registrations will be disabled. |
| mastodon.smtp.auth_method | string | `"plain"` |  |
| mastodon.smtp.ca_file | string | `"/etc/ssl/certs/ca-certificates.crt"` |  |
| mastodon.smtp.delivery_method | string | `"smtp"` |  |
| mastodon.smtp.domain | string | `nil` |  |
| mastodon.smtp.enable_starttls | string | `"auto"` |  |
| mastodon.smtp.existingSecret | string | `""` | Instead of defining login/password above, you can specify the name of an existing secret here. Login and password must be located in keys named `login` and `password` respectively. |
| mastodon.smtp.from_address | string | `"notifications@example.com"` |  |
| mastodon.smtp.login | string | `nil` |  |
| mastodon.smtp.openssl_verify_mode | string | `"peer"` |  |
| mastodon.smtp.password | string | `nil` |  |
| mastodon.smtp.port | int | `587` |  |
| mastodon.smtp.reply_to | string | `nil` |  |
| mastodon.smtp.return_path | string | `nil` |  |
| mastodon.smtp.server | string | `"smtp.mailgun.org"` |  |
| mastodon.smtp.tls | bool | `false` |  |
| mastodon.streaming.affinity | object | `{}` | Affinity for Streaming Pods, overwrites .Values.affinity |
| mastodon.streaming.base_url | string | `nil` | The base url for streaming can be set if the streaming API is deployed to a different domain/subdomain. |
| mastodon.streaming.podSecurityContext | object | `{}` | Pod Security Context for Streaming Pods, overwrites .Values.podSecurityContext |
| mastodon.streaming.port | int | `4000` |  |
| mastodon.streaming.replicas | int | `1` | Number of Streaming Pods running |
| mastodon.streaming.resources | Streaming Container | `{}` | Resources for Streaming Pods, overwrites .Values.resources |
| mastodon.streaming.securityContext | Streaming Container | `{}` | Security Context for Streaming Pods, overwrites .Values.securityContext |
| mastodon.streaming.workers | int | `1` | this should be set manually since os.cpus() returns the number of CPUs on the node running the pod, which is unrelated to the resources allocated to the pod by k8s |
| mastodon.web.affinity | object | `{}` | Affinity for Web Pods, overwrites .Values.affinity |
| mastodon.web.maxThreads | string | `"5"` |  |
| mastodon.web.minThreads | string | `"5"` | Puma-specific options. Below values are based on default behavior in config/puma.rb when no custom values are provided. |
| mastodon.web.persistentTimeout | string | `"20"` |  |
| mastodon.web.podSecurityContext | object | `{}` | Pod Security Context for Web Pods, overwrites .Values.podSecurityContext |
| mastodon.web.port | int | `3000` |  |
| mastodon.web.replicas | int | `1` | Number of Web Pods running |
| mastodon.web.resources | Web Container | `{}` | Resources for Web Pods, overwrites .Values.resources |
| mastodon.web.securityContext | Web Container | `{}` | Security Context for Web Pods, overwrites .Values.securityContext |
| mastodon.web.workers | string | `"2"` |  |
| mastodon.web_domain | string | `nil` | Use of WEB_DOMAIN requires careful consideration: https://docs.joinmastodon.org/admin/config/#federation You must redirect the path LOCAL_DOMAIN/.well-known/ to WEB_DOMAIN/.well-known/ as described Example: mastodon.example.com |
| nameOverride | string | `""` |  |
| podAnnotations | object | `{}` | Kubernetes manages pods for jobs and pods for deployments differently, so you might need to apply different annotations to the two different sets of pods. The annotations set with podAnnotations will be added to all deployment-managed pods. |
| podSecurityContext | object | `{"fsGroup":991,"runAsGroup":991,"runAsUser":991}` | https://github.com/mastodon/mastodon/blob/main/Dockerfile#L75  if you manually change the UID/GID environment variables, ensure these values match: |
| postgresql.auth.database | string | `"mastodon_production"` |  |
| postgresql.auth.existingSecret | string | `""` |  |
| postgresql.auth.password | string | `""` |  |
| postgresql.auth.username | string | `"mastodon"` |  |
| postgresql.enabled | bool | `true` | disable if you want to use an existing db; in which case the values below must match those of that external postgres instance |
| redis.auth.existingSecret | string | `""` |  |
| redis.auth.password | string | `""` | you must set a password; the password generated by the redis chart will be rotated on each upgrade: |
| redis.enabled | bool | `true` |  |
| redis.hostname | string | `""` |  |
| redis.port | int | `6379` |  |
| resources | object | `{}` | Default resources for all Deployments and jobs unless overwritten |
| revisionPodAnnotation | bool | `true` |  |
| serviceAccount.annotations | object | `{}` | Annotations to add to the service account |
| serviceAccount.create | bool | `true` | Specifies whether a service account should be created |
| serviceAccount.name | string | `""` | The name of the service account to use. If not set and create is true, a name is generated using the fullname template |

----------------------------------------------
Autogenerated from chart metadata using [helm-docs v1.11.0](https://github.com/norwoodj/helm-docs/releases/v1.11.0)
